use utf8;
package NACL::ResourceList::Schema::Result::PrimaryKey;

=head1 NAME

NACL::ResourceList::Schema::Result::PrimaryKey

=cut

use strict;
use warnings;

use base 'DBIx::Class::Core';

=head1 TABLE: C<Primary_Keys>

=cut

__PACKAGE__->table("Primary_Keys");

=head1 ACCESSORS

=head2 id

  data_type: 'integer'
  is_auto_increment: 1
  is_nullable: 0

=head2 package_id

  data_type: 'integer'
  is_foreign_key: 1
  is_nullable: 1

=head2 element_id

  data_type: 'integer'
  is_foreign_key: 1
  is_nullable: 1

=head2 attribute

  data_type: 'varchar'
  is_nullable: 1
  size: 45

=head2 value

  data_type: 'varchar'
  is_nullable: 1
  size: 45

=cut

__PACKAGE__->add_columns(
  "id",
  { data_type => "integer", is_auto_increment => 1, is_nullable => 0 },
  "package_id",
  { data_type => "integer", is_foreign_key => 1, is_nullable => 1 },
  "element_id",
  { data_type => "integer", is_foreign_key => 1, is_nullable => 1 },
  "attribute",
  { data_type => "varchar", is_nullable => 1, size => 245 },
  "value",
  { data_type => "varchar", is_nullable => 1, size => 1024 },
);

=head1 PRIMARY KEY

=over 4

=item * L</id>

=back

=cut

__PACKAGE__->set_primary_key("id");

=head1 RELATIONS

=head2 package

Type: belongs_to

Related object: L<NACL::ResourceList::Schema::Result::Package>

=cut

__PACKAGE__->belongs_to(
  "package",
  "NACL::ResourceList::Schema::Result::Package",
  { id => "package_id" },
  {
    is_deferrable => 0,
    join_type     => "LEFT",
    on_delete     => "RESTRICT",
    on_update     => "CASCADE",
  },
);

=head2 element

Type: belongs_to

Related object: L<NACL::ResourceList::Schema::Result::Element>

=cut

__PACKAGE__->belongs_to(
  "element",
  "NACL::ResourceList::Schema::Result::Element",
  { id => "element_id" },
  {
    is_deferrable => 0,
    join_type     => "LEFT",
    on_delete     => "RESTRICT",
    on_update     => "CASCADE",
  },
);

1;
